package ambev

import static org.springframework.http.HttpStatus.*
import grails.transaction.Transactional

import ambev.entities.Department
import ambev.Facade

@Transactional(readOnly = true)
class DepartmentController {
    private facade = Facade.getInstance()
    static allowedMethods = [save: "POST", update: "PUT", delete: "DELETE"]

    def index(Integer max) {
        params.max = Math.min(max ?: 10, 100)
        facade.listDepartments(params)
    }

    def show(Department departmentInstance) {
        [departmentInstance: departmentInstance]
    }

    def create() {
        facade.createDepartment(params)
    }

    @Transactional
    def save(Department departmentInstance) {

        if (departmentInstance == null) {
            notFound(request)
            return
        }

        if (departmentInstance.hasErrors()) {
            respond departmentInstance.errors, view:'create'
            return
        }

        facade.saveDepartment(departmentInstance)

        request.withFormat {
                form {
                flash.message = message(code: 'default.created.message', args: [message(code: 'departmentInstance.label', default: 'Department'), departmentInstance.id])
                redirect departmentInstance
            }
            '*' { respond departmentInstance, [status: CREATED] }
        }

    }

    def edit(Department departmentInstance) {
        [departmentInstance: departmentInstance]
    }

    @Transactional
    def update(Department departmentInstance) {

        if (departmentInstance == null) {
            notFound()
            return
        }

        if (departmentInstance.hasErrors()) {
            respond departmentInstance.errors, view:'edit'
            return
        }

        facade.updateDepartment(departmentInstance)

        request.withFormat {
            form {
                flash.message = message(code: 'default.updated.message', args: [message(code: 'Department.label', default: 'Department'), departmentInstance.id])
                redirect departmentInstance
            }
            '*'{ respond departmentInstance, [status: OK] }
        }

    }

    @Transactional
    def delete(Department departmentInstance) {
        
        if (departmentInstance == null) {
            notFound()
            return
        }

        facade.deleteDepartment(departmentInstance)

        request.withFormat {
            form {
                flash.message = message(code: 'default.deleted.message', args: [message(code: 'Department.label', default: 'Department'), departmentInstance.id])
                redirect action:"index", method:"GET"
            }
            '*'{ render status: NO_CONTENT }
        }

    }

    protected void notFound() {
        request.withFormat {
            form {
                flash.message = message(code: 'default.not.found.message', args: [message(code: 'departmentInstance.label', default: 'Department'), params.id])
                redirect action: "index", method: "GET"
            }
            '*'{ render status: NOT_FOUND }
        }
    }

}
