package ambev

import static org.springframework.http.HttpStatus.*
import grails.transaction.Transactional

import ambev.entities.Machine
import ambev.Facade

@Transactional(readOnly = true)
class MachineController {
    private facade = Facade.getInstance()
    static allowedMethods = [save: "POST", update: "PUT", delete: "DELETE"]

    def index(Integer max) {
        params.max = Math.min(max ?: 10, 100)
        facade.listMachines(params)
    }

    def show(Machine machineInstance) {
        [machineInstance: machineInstance]
    }

    def create() {
        facade.createMachine(params)
    }

    @Transactional
    def save(Machine machineInstance) {

        if (machineInstance == null) {
            notFound(request)
            return
        }

        if (machineInstance.hasErrors()) {
            respond machineInstance.errors, view:'create'
            return
        }

        facade.saveMachine(machineInstance)

        request.withFormat {
                form {
                flash.message = message(code: 'default.created.message', args: [message(code: 'machineInstance.label', default: 'Machine'), machineInstance.id])
                redirect machineInstance
            }
            '*' { respond machineInstance, [status: CREATED] }
        }

    }

    def edit(Machine machineInstance) {
        [machineInstance: machineInstance]
    }

    @Transactional
    def update(Machine machineInstance) {

        if (machineInstance == null) {
            notFound()
            return
        }

        if (machineInstance.hasErrors()) {
            respond machineInstance.errors, view:'edit'
            return
        }

        facade.updateMachine(machineInstance)

        request.withFormat {
            form {
                flash.message = message(code: 'default.updated.message', args: [message(code: 'Machine.label', default: 'Machine'), machineInstance.id])
                redirect machineInstance
            }
            '*'{ respond machineInstance, [status: OK] }
        }

    }

    @Transactional
    def delete(Machine machineInstance) {
        
        if (machineInstance == null) {
            notFound()
            return
        }

        facade.deleteMachine(machineInstance)

        request.withFormat {
            form {
                flash.message = message(code: 'default.deleted.message', args: [message(code: 'Machine.label', default: 'Machine'), machineInstance.id])
                redirect action:"index", method:"GET"
            }
            '*'{ render status: NO_CONTENT }
        }

    }

    protected void notFound() {
        request.withFormat {
            form {
                flash.message = message(code: 'default.not.found.message', args: [message(code: 'machineInstance.label', default: 'Machine'), params.id])
                redirect action: "index", method: "GET"
            }
            '*'{ render status: NOT_FOUND }
        }
    }

}
