package ambev

import static org.springframework.http.HttpStatus.*
import grails.transaction.Transactional

import ambev.entities.Task
import ambev.Facade

@Transactional(readOnly = true)
class TaskController {
    private facade = Facade.getInstance()
    static allowedMethods = [save: "POST", update: "PUT", delete: "DELETE"]

    def index(Integer max) {
        params.max = Math.min(max ?: 10, 100)
        facade.listTasks(params)
    }

    def show(Task taskInstance) {
        [taskInstance: taskInstance]
    }

    def create() {
        facade.createTask(params)
    }

    @Transactional
    def save(Task taskInstance) {

        if (taskInstance == null) {
            notFound(request)
            return
        }

        if (taskInstance.hasErrors()) {
            respond taskInstance.errors, view:'create'
            return
        }

        facade.saveTask(taskInstance)

        request.withFormat {
                form {
                flash.message = message(code: 'default.created.message', args: [message(code: 'taskInstance.label', default: 'Task'), taskInstance.id])
                redirect taskInstance
            }
            '*' { respond taskInstance, [status: CREATED] }
        }

    }

    def edit(Task taskInstance) {
        [taskInstance: taskInstance]
    }

    @Transactional
    def update(Task taskInstance) {

        if (taskInstance == null) {
            notFound()
            return
        }

        if (taskInstance.hasErrors()) {
            respond taskInstance.errors, view:'edit'
            return
        }

        facade.updateTask(taskInstance)

        request.withFormat {
            form {
                flash.message = message(code: 'default.updated.message', args: [message(code: 'Task.label', default: 'Task'), taskInstance.id])
                redirect taskInstance
            }
            '*'{ respond taskInstance, [status: OK] }
        }

    }

    @Transactional
    def delete(Task taskInstance) {
        
        if (taskInstance == null) {
            notFound()
            return
        }

        facade.deleteTask(taskInstance)

        request.withFormat {
            form {
                flash.message = message(code: 'default.deleted.message', args: [message(code: 'Task.label', default: 'Task'), taskInstance.id])
                redirect action:"index", method:"GET"
            }
            '*'{ render status: NO_CONTENT }
        }

    }

    protected void notFound() {
        request.withFormat {
            form {
                flash.message = message(code: 'default.not.found.message', args: [message(code: 'taskInstance.label', default: 'Task'), params.id])
                redirect action: "index", method: "GET"
            }
            '*'{ render status: NOT_FOUND }
        }
    }

}