package ambev

import static org.springframework.http.HttpStatus.*
import grails.transaction.Transactional

import ambev.entities.User
import ambev.Facade

@Transactional(readOnly = true)
class UserController {
    private facade = Facade.getInstance()
    static allowedMethods = [save: "POST", update: "PUT", delete: "DELETE"]

    def index(Integer max) {
        params.max = Math.min(max ?: 10, 100)
        facade.listUsers(params)
    }

    def show(User userInstance) {
        [userInstance: userInstance]
    }

    def create() {
        facade.createUser(params)
    }

    @Transactional
    def save(User userInstance) {

        if (userInstance == null) {
            notFound(request)
            return
        }

        if (userInstance.hasErrors()) {
            respond userInstance.errors, view:'create'
            return
        }

        facade.saveUser(userInstance)

        request.withFormat {
                form {
                flash.message = message(code: 'default.created.message', args: [message(code: 'userInstance.label', default: 'User'), userInstance.id])
                redirect userInstance
            }
            '*' { respond userInstance, [status: CREATED] }
        }

    }

    def edit(User userInstance) {
        [userInstance: userInstance]
    }

    @Transactional
    def update(User userInstance) {

        if (userInstance == null) {
            notFound()
            return
        }

        if (userInstance.hasErrors()) {
            respond userInstance.errors, view:'edit'
            return
        }

        facade.updateUser(userInstance)

        request.withFormat {
            form {
                flash.message = message(code: 'default.updated.message', args: [message(code: 'User.label', default: 'User'), userInstance.id])
                redirect userInstance
            }
            '*'{ respond userInstance, [status: OK] }
        }

    }

    @Transactional
    def delete(User userInstance) {
        
        if (userInstance == null) {
            notFound()
            return
        }

        facade.deleteUser(userInstance)

        request.withFormat {
            form {
                flash.message = message(code: 'default.deleted.message', args: [message(code: 'User.label', default: 'User'), userInstance.id])
                redirect action:"index", method:"GET"
            }
            '*'{ render status: NO_CONTENT }
        }

    }

    protected void notFound() {
        request.withFormat {
            form {
                flash.message = message(code: 'default.not.found.message', args: [message(code: 'userInstance.label', default: 'User'), params.id])
                redirect action: "index", method: "GET"
            }
            '*'{ render status: NOT_FOUND }
        }
    }

}
